Reconvergence-driven cuts
-------------------------

**Header:** ``mockturtle/algorithms/reconv_cut.hpp``

.. doxygenstruct:: mockturtle::reconvergence_driven_cut_parameters

.. doxygenfunction:: mockturtle::reconvergence_driven_cut(Ntk const&, node<Ntk> const&, reconvergence_driven_cut_parameters const&, reconvergence_driven_cut_statistics*)

.. doxygenfunction:: mockturtle::reconvergence_driven_cut(Ntk const&, signal<Ntk> const&, reconvergence_driven_cut_parameters const&, reconvergence_driven_cut_statistics*)

.. doxygenfunction:: mockturtle::reconvergence_driven_cut(Ntk const&, std::vector<node<Ntk>> const&, reconvergence_driven_cut_parameters const&, reconvergence_driven_cut_statistics*)
